@@ -20,46 +20,9 @@ sub CLI {
 # load app config
 my $cfg = P->cfg->read( "$ENV->{DATA_DIR}/cfg.yaml", params => { DATA_DIR => $ENV->{DATA_DIR} } );
 
-my $app_cfg = {           #
-    cfg => {
+$cfg->{api}->{backend} = $cfg->{db};
 
-        # DB
-        db => $cfg->{db},
-
-        # SERVER
-        server => {
-            default => {
-                namespace   => undef,
-                listen      => undef,
-                server_name => [],
-            },
-        },
-
-        # NODE
-        node => {
-            server => $cfg->{node}->{server},
-            listen => $cfg->{node}->{listen},
-        },
-
-        # API
-        api => {
-            backend => $cfg->{db},
-            node    => {
-                workers => undef,
-                argon   => {
-                    argon2_time        => 3,
-                    argon2_memory      => '64M',
-                    argon2_parallelism => 1,
-                },
-            },
-        },
-    },
-    devel => $ENV->{cli}->{opt}->{devel},
-};
-
-Pcore::App->merge_config( $app_cfg, $cfg );
-
-my $app = <: $module_name :>->new($app_cfg);
+my $app = <: $module_name :>->new( $ENV->{cli}->{opt}->{devel}, $cfg );
 
 my $cv = P->cv;
 
